Learn R Programming

micEconSNQP (version 0.6-6)

snqProfitShadowPrices: Shadow Prices of a SNQ Profit function

Description

Calculates the shadow prices of a Symmetric Normalized Quadratic (SNQ) profit function.

Usage

snqProfitShadowPrices( priceNames, fixNames, estResult = NULL, data = estResult$data, weights = estResult$weights, scalingFactors = estResult$scalingFactors, coef = estResult$coef, form = estResult$form )

Arguments

priceNames
a vector of strings containing the names of netput prices.
fixNames
an optional vector of strings containing the names of the quantities of (quasi-)fix inputs.
estResult
object returned by snqProfitEst.
data
a data frame containing the data.
weights
vector of weights of prices used for normalization.
scalingFactors
factors to scale prices (see details).
coef
a list containing the coefficients (at least delta and gamma).
form
the functional form to be estimated (see details).

See Also

snqProfitEst, snqProfitCalc and snqProfitEla.

Examples

Run this code
   data( germanFarms, package = "micEcon" )
   germanFarms$qOutput   <- germanFarms$vOutput   / germanFarms$pOutput
   germanFarms$qVarInput <- -germanFarms$vVarInput / germanFarms$pVarInput
   germanFarms$qLabor    <- -germanFarms$qLabor
   germanFarms$time      <- c( 0:19 )
   priceNames <- c( "pOutput", "pVarInput", "pLabor" )
   quantNames <- c( "qOutput", "qVarInput", "qLabor" )
   fixNames <- c( "land", "time" )

   estResult <- snqProfitEst( priceNames, quantNames, fixNames, data = germanFarms )

   snqProfitShadowPrices( priceNames, fixNames, estResult )

Run the code above in your browser using DataLab